==> rucy-0.4.0.tar.gz: rucy-0.4.0/lib_core/rucy/priv.rb <==
# $Id: priv.rb,v 1.8 2004/12/17 17:07:56 toki Exp $

require 'rucy/rep'

module Rucy
  class Privilege
    def initialize(non_privilege_user, non_privilege_group, rep=Repository::DEFAULT)
      @non_privilege_user = non_privilege_user
      @non_privilege_group = non_privilege_group
      @rep = rep
      @Etc = @rep.fetch(:Etc)
      @File = @rep.fetch(:File)
      @Process = @rep.fetch(:Process)
    end

    attr_reader :non_privilege_user
    attr_reader :non_privilege_group

    def uid(user)
      case (user)
      when Numeric
	return user
      else
	return @Etc.getpwnam(user).uid
      end
    end

    def gid(group)
      case (group)
      when Numeric
	return group
      else
	return @Etc.getgrnam(group).gid
      end
    end

    def privileged_user?
      @Process.euid == 0
    end

    def cancel_privilege
      if (@non_privilege_group) then
	gid = gid(@non_privilege_group)
	@Process.gid = gid
	@Process.egid = gid
      end
      if (@non_privilege_user) then
	uid = uid(@non_privilege_user)
	@Process.uid = uid
	@Process.euid = uid
      end

      nil
    end

    def chown(path)
      if (@non_privilege_user || @non_privilege_group) then
	uid = (@non_privilege_user) ? uid(@non_privilege_user) : nil
	gid = (@non_privilege_group) ? gid(@non_privilege_group) : nil
	@File.chown(uid, gid, path)
      end

      nil
    end

    def touch(path, no_create=false)
      if (@File.exist? path) then
	chown(path)
      else
	unless (no_create) then
	  @File.open(path, File::WRONLY | File::CREAT | File::EXCL) {}
	  chown(path)
	end
      end

      nil
    end
  end
end

==> rucy-0.5.0.tar.gz: rucy-0.5.0/lib_core/rucy/priv.rb <==
# $Id: priv.rb,v 1.9 2005/02/11 16:25:11 toki Exp $

require 'rucy/rep'

module Rucy
  class Privilege
    def initialize(non_privilege_user, non_privilege_group, rep=Repository::DEFAULT)
      @non_privilege_user = non_privilege_user
      @non_privilege_group = non_privilege_group
      @rep = rep
      @Etc = @rep.fetch(:Etc_module)
      @File = @rep.fetch(:File_class)
      @Process = @rep.fetch(:Process_module)
    end

    attr_reader :non_privilege_user
    attr_reader :non_privilege_group

    def uid(user)
      case (user)
      when Numeric
	return user
      else
	return @Etc.getpwnam(user).uid
      end
    end

    def gid(group)
      case (group)
      when Numeric
	return group
      else
	return @Etc.getgrnam(group).gid
      end
    end

    def privileged_user?
      @Process.euid == 0
    end

    def cancel_privilege
      if (@non_privilege_group) then
	gid = gid(@non_privilege_group)
	@Process.gid = gid
	@Process.egid = gid
      end
      if (@non_privilege_user) then
	uid = uid(@non_privilege_user)
	@Process.uid = uid
	@Process.euid = uid
      end

      nil
    end

    def chown(path)
      if (@non_privilege_user || @non_privilege_group) then
	uid = (@non_privilege_user) ? uid(@non_privilege_user) : nil
	gid = (@non_privilege_group) ? gid(@non_privilege_group) : nil
	@File.chown(uid, gid, path)
      end

      nil
    end

    def touch(path, no_create=false)
      if (@File.exist? path) then
	chown(path)
      else
	unless (no_create) then
	  @File.open(path, File::WRONLY | File::CREAT | File::EXCL) {}
	  chown(path)
	end
      end

      nil
    end
  end
end
